@@ -380,8 +380,9 @@ def execute_safe_sql(sql_query, force_execute=False):
         # Ask for execution approval
         try:
             # Check if stdin is available for input
-            if not sys.stdin.isatty():
-                # No interactive terminal - auto-approve
+            # Also check if we're in test mode (PYTEST_CURRENT_TEST env var)
+            if not sys.stdin.isatty() or os.getenv('PYTEST_CURRENT_TEST'):
+                # No interactive terminal or in test mode - auto-approve
                 rich_console.print("\n[dim]Auto-approving (no interactive terminal)[/dim]")
             else:
                 execute = input("\n🤔 Execute this SQL query? (y/n): ").strip().lower()
@@ -960,12 +961,8 @@ def main():
     global dbt, LLM_AVAILABLE
     
     # Show banner first ONLY for CLI mode with query (not for Textual app)
-    # Banner should only show when we'll use Rich/CLI interface, not Textual interface
-    # IMPORTANT: Never show banner in --no-repl mode or when query is provided
-    if args.query and not args.no_repl and args.textual and (not sys.stdin.isatty() or not LLM_AVAILABLE):
-        # Get LLM model info for banner
-        llm_model = os.getenv('SQLBOT_LLM_MODEL', 'gpt-5') if LLM_AVAILABLE else None
-        show_banner(is_no_repl=True, profile=args.profile, llm_model=llm_model, llm_available=LLM_AVAILABLE)
+    # Banner logic: Don't show banner when query is provided from command line
+    # Banner will be shown later in interactive mode startup if appropriate
     
     # Initialize everything after banner display
     if dbt is None:
@@ -1146,16 +1143,14 @@ def main():
     if args.query:
         # Join all query arguments as a single query
         query = ' '.join(args.query)
-        
-        # Set global mode flags
+
+        # Set global mode flags (but don't print messages yet - banner must come first)
         if args.preview:
             PREVIEW_MODE = True
-            rich_console.print("Preview Mode Enabled - SQL will be shown before execution")
-        
+
         if args.dangerous:
             READONLY_MODE = False
             READONLY_CLI_MODE = True  # CLI mode - safeguards explicitly disabled
-            rich_console.print("Dangerous Mode Enabled - Safeguards disabled, all operations allowed")
         
         if args.history:
             SHOW_HISTORY = True
@@ -1174,9 +1169,19 @@ def main():
             return
         else:
             # Default: text-based CLI mode
-            # Add spacing after command line when not showing banner
-            rich_console.print()
-            rich_console.print()
+            # Show banner when NOT in --no-repl mode
+            if not args.no_repl:
+                show_banner(is_no_repl=False, profile=args.profile, llm_model=llm_model, llm_available=LLM_AVAILABLE)
+            else:
+                # In --no-repl mode, just add spacing
+                rich_console.print()
+                rich_console.print()
+
+            # Show mode messages (both in repl and no-repl modes)
+            if args.preview:
+                rich_console.print("Preview Mode Enabled - SQL will be shown before execution")
+            if args.dangerous:
+                rich_console.print("Dangerous Mode Enabled - Safeguards disabled, all operations allowed")
 
             # Execute the initial query using unified display system
             _execute_query_cli_mode(query, rich_console)
